@@ -15,7 +15,7 @@ use Text::Diff 1.44 qw(diff);
 
 use Moo;
 
-our $VERSION = '0.66';
+our $VERSION = '0.68';
 
 has argv => (
     is      => 'ro',
@@ -23,6 +23,16 @@ has argv => (
     default => q{}
 );
 
+# This really belongs in Code::TidyAll::Role::RunsCommand but moving it there
+# breaks plugins not in the core distro that expect to just inherit from this
+# module and be able to specify a cmd attribute.
+has cmd => (
+    is      => 'ro',
+    isa     => t('NonEmptyStr'),
+    lazy    => 1,
+    builder => '_build_cmd',
+);
+
 has diff_on_tidy_error => (
     is      => 'ro',
     isa     => t('Bool'),
@@ -241,7 +251,7 @@ Code::TidyAll::Plugin - Create plugins for tidying or validating code
 
 =head1 VERSION
 
-version 0.66
+version 0.68
 
 =head1 SYNOPSIS
 
