@@ -10,6 +10,7 @@ use IPC::Run3 qw( run3 );
 use Path::Tiny qw(cwd path);
 
 use Test::Class::Most parent => 'TestHelper::Test::Class';
+use Test::Fatal;
 
 sub test_plugin {"+TestHelper::Plugin::$_[0]"}
 my %UpperText
@@ -438,7 +439,7 @@ sub test_errors : Tests {
         Code::TidyAll->new(
             root_dir => $root_dir,
             plugins  => { 'DoesNotExist' => { select => '**/*' } }
-        )->plugin_objects;
+        )->_plugin_objects;
     }
     qr/could not load plugin class/;
 
@@ -448,7 +449,7 @@ sub test_errors : Tests {
             plugins  => {
                 test_plugin('UpperText') => { select => '**/*', bad_option => 1, worse_option => 2 }
             }
-        )->plugin_objects;
+        )->_plugin_objects;
     }
     qr/unknown options/;
 
@@ -647,7 +648,7 @@ sub test_inc : Tests {
     );
 
     is_deeply(
-        [ sort map { ref($_) } @{ $ct->plugin_objects } ],
+        [ sort map { ref($_) } @{ $ct->_plugin_objects } ],
         [qw( Bar Foo TestHelper::Plugin::UpperText )],
         'when inc is provided it is used when loading plugins'
     );
@@ -658,4 +659,47 @@ sub test_inc : Tests {
     $ct->process_paths($file);
 }
 
+sub test_selected_plugins : Tests {
+    my $self = shift;
+
+    my $root_dir = $self->create_dir( { 'foo.txt' => 'abc' } );
+
+    my $ct = Code::TidyAll->new(
+        plugins => {
+            %UpperText,
+            %ReverseFoo,
+            %RepeatFoo,
+            %CheckUpper,
+            %AToZ,
+        },
+        selected_plugins => [ test_plugin('UpperText'), test_plugin('ReverseFoo') ],
+        root_dir         => $root_dir,
+    );
+
+    is_deeply(
+        [ sort map { ref($_) } @{ $ct->_plugin_objects } ],
+        [qw( TestHelper::Plugin::ReverseFoo TestHelper::Plugin::UpperText )],
+        'when selected_plugins is provided only those plugins are used'
+    );
+
+    $ct = Code::TidyAll->new(
+        plugins => {
+            %UpperText,
+            %ReverseFoo,
+            %RepeatFoo,
+            %CheckUpper,
+            %AToZ,
+        },
+        selected_plugins =>
+            [ test_plugin('UpperText'), test_plugin('ReverseFoo'), 'DoesNotExist', 'NorDoesThis' ],
+        root_dir => $root_dir,
+    );
+
+    like(
+        exception { $ct->_plugin_objects },
+        qr/\QAsked for unknown plugins: [DoesNotExist NorDoesThis]/,
+        'exception is thrown when selected_plugins include unknown plugins'
+    );
+}
+
 1;
